<?php

namespace Teknisa\GQL\Modules\Atendimento\Services;

use Doctrine\DBAL\ParameterType;

class Gql00800OcorrenciaAtendimentoQualificacaoAutomaticaFornecedoresService 
{

    protected $connection;
    protected $newCode;

    public function __construct($entityManager, $environment, $newCode)
    {
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
        $this->newCode = $newCode;
    }
    
    public function insertData($row)
    {

        $NROCORRMOV =  $this->newCode->getCodeByTableName('MOVOOCOR' . $this->environment->getCdFilial(), $this->environment->getNrOrgTrab());
        
        $params = $this->getParams($row, $NROCORRMOV);

        $params = $this->getRightCode($params, $row);
        
        $query = "INSERT INTO MOVOCORR (CDFILILANCMO, NROCORRMOV, CDFILIAL, CDFORNECED, CDCLIENTE, CDPROSPECT, DTOCORRMOV, NMPESSIDETOC, CDOPERADOR, 
        CDGRPOCOR, CDOCORR, CDPRODUTO, CDDESTPROD, CDSEGMER, NRLOTEESTQ, NRSUBLOTE, NMPESSAUTOOC, DSSUMARIAOC,
        CDFILIALNF, NRLANCTONF, DSCLASSOCOR, CDFORNTRANSP, NRTAREFA, CDMARCA, DSSIFPRODOCORR, DSCOMPLLOTEOCOR, DTENTRMOVOCORR, IDSITUMOVOCORR, NRLISTAUTFORN )
            values
        (:CDFILILANCMO, :NROCORRMOV, :CDFILIAL, :CDFORNECED, :CDCLIENTE, :CDPROSPECT, TRUNC(SYSDATE), :NMPESSIDETOC, :CDOPERADOR, 
        :CDGRPOCOR, :CDOCORR, :CDPRODUTO, :CDDESTPROD, :CDSEGMER, :NRLOTEESTQ, :NRSUBLOTE, :NMPESSAUTOOC, :DSSUMARIAOC,
        :CDFILIALNF, :NRLANCTONF, :DSCLASSOCOR, :CDFORNTRANSP, :NRTAREFA, :CDMARCA, :DSSIFPRODOCORR, :DSCOMPLLOTEOCOR, :DTENTRMOVOCORR, :IDSITUMOVOCORR, :NRLISTAUTFORN)
        ";
        try {

            $this->connection->beginTransaction();

            $std = $this->connection->prepare($query);
            $std->execute($params);

            $this->connection->commit();
            
            $DATA = array (
                'NROCORRMOV'    => $params['NROCORRMOV'],
                'CDFILILANCMO'  => $params['CDFILILANCMO']
            );  
            
            return $DATA;
            
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }

    }

    public function updateData($row)
    {
        
        $params = $this->getParams($row, $row['NROCORRMOV']);

        $params['CDFORNECED'] = $row['CDFORNECED'] ?? null;
        $params['CDCLIENTE'] = $row['CDCLIENTE'] ?? null;
        $params['CDPROSPECT'] = $row['CDPROSPECT'] ?? null;
        
        $DTOCORRMOV = explode(" ", $row["DTOCORRMOV"])[0];

        $query = "UPDATE MOVOCORR
            SET
            CDFILIAL = :CDFILIAL, 
            CDFORNECED = :CDFORNECED, 
            CDCLIENTE = :CDCLIENTE, 
            CDPROSPECT = :CDPROSPECT, 
            DTOCORRMOV = '{$DTOCORRMOV}', 
            NMPESSIDETOC = :NMPESSIDETOC, 
            CDOPERADOR = :CDOPERADOR, 
            CDGRPOCOR = :CDGRPOCOR, 
            CDOCORR = :CDOCORR, 
            CDPRODUTO = :CDPRODUTO,
            CDDESTPROD = :CDDESTPROD,
            CDSEGMER = :CDSEGMER, 
            NRLOTEESTQ = :NRLOTEESTQ, 
            NRSUBLOTE = :NRSUBLOTE,
            NMPESSAUTOOC = :NMPESSAUTOOC, 
            DSSUMARIAOC = :DSSUMARIAOC,
            CDFILIALNF = :CDFILIALNF, 
            NRLANCTONF = :NRLANCTONF, 
            DSCLASSOCOR = :DSCLASSOCOR, 
            CDFORNTRANSP = :CDFORNTRANSP, 
            NRTAREFA = :NRTAREFA,
            CDMARCA   = :CDMARCA,
            DSSIFPRODOCORR  = :DSSIFPRODOCORR,
            DSCOMPLLOTEOCOR = :DSCOMPLLOTEOCOR,
            DTENTRMOVOCORR = :DTENTRMOVOCORR,
            IDSITUMOVOCORR = :IDSITUMOVOCORR,
            NRLISTAUTFORN  = :NRLISTAUTFORN
                WHERE
          CDFILILANCMO = :CDFILILANCMO AND
          NROCORRMOV = :NROCORRMOV";
        try {

            $this->connection->beginTransaction();

            $std = $this->connection->prepare($query);
            $std->execute($params);

            $this->connection->commit();
            
            $DATA = array (
                'NROCORRMOV'    => $params['NROCORRMOV'],
                'CDFILILANCMO'  => $params['CDFILILANCMO']
            );       
            
            return $DATA;
            
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    protected function getRightCode($params, $row)
    {  
        
        $value = $row['CDFORNECED'];

        $params['CDFORNECED'] = null;
        $params['CDCLIENTE'] = null;
        $params['CDPROSPECT'] = null;

        if($row["TIPO"] === 'F')
        {
            $params['CDFORNECED'] = $value;

        } else if($row["TIPO"] === 'C') {

            $params['CDCLIENTE'] = $value;

        } else if($row["TIPO"] === 'P') {

            $params['CDPROSPECT'] = $value;

        }

        return $params;
        
    }
    
    protected function getParams($row, $NROCORRMOV)
    {
        $CDFILIAL        = $row["CDFILIAL"]   ?? null;
        $CDGRPOCOR       = $row["CDGRPOCOR"] ?? null;
        $CDOCORR         = $row["CDOCORR"] ?? null;
        $CDPRODUTO       = $row["CDPRODUTO"] ?? null;
        $CDDESTPROD      = $row["CDDESTPROD"] ?? null;
        $CDSEGMER        = $row["CDSEGMER"] ?? null;
        $NRLOTEESTQ      = $row["NRLOTEESTQ"] ?? null;
        $NRSUBLOTE       = $row["NRSUBLOTE"] ?? null;
        $DSSUMARIAOC     = $row["DSSUMARIAOC"] ?? null;
        $DSCLASSOCOR     = $row["DSCLASSOCOR"] ?? null;
        $CDFORNTRANSP    = $row["CDFORNTRANSP"] ?? null;
        $NRTAREFA        = $row["NRTAREFA"] ?? null;
        $CDMARCA         = $row["CDMARCA"] ?? null;
        $DSSIFPRODOCORR  = $row["DSSIFPRODOCORR"] ?? null;
        $DSCOMPLLOTEOCOR = $row["DSCOMPLLOTEOCOR"] ?? null;
        $IDSITUMOVOCORR  = $row["IDSITUMOVOCORR"] ?? null;
        $NMPESSIDETOC    = $row["NMPESSIDETOC"] ?? null;
        $NMPESSAUTOOC    = $row["NMPESSAUTOOC"] ?? null;
        $NRLANCTONF      = $row["NRLANCTONF"] ?? null;
        $CDFILIALNF      = $row["CDFILIALNF"] ?? null;
        $NRLISTAUTFORN   = $row["NRLISTAUTFORN"] ?? null;
        $DTENTRMOVOCORR  = $row["DTENTRMOVOCORR"] ?? null;
        
        
        return [

            'CDFILIAL'        => $CDFILIAL,
            'CDFILIALNF'      => $CDFILIALNF,
            'CDGRPOCOR'       => $CDGRPOCOR,
            'CDOCORR'         => $CDOCORR,
            'CDPRODUTO'       => $CDPRODUTO,
            'CDDESTPROD'      => $CDDESTPROD,
            'CDSEGMER'        => $CDSEGMER,
            'NRLOTEESTQ'      => $NRLOTEESTQ,
            'NRSUBLOTE'       => $NRSUBLOTE,
            'DSSUMARIAOC'     => $DSSUMARIAOC,
            'DSCLASSOCOR'     => $DSCLASSOCOR,
            'CDFORNTRANSP'    => $CDFORNTRANSP,
            'NRTAREFA'        => $NRTAREFA,
            'CDMARCA'         => $CDMARCA,
            'DSSIFPRODOCORR'  => $DSSIFPRODOCORR,
            'DSCOMPLLOTEOCOR' => $DSCOMPLLOTEOCOR,
            'IDSITUMOVOCORR'  => $IDSITUMOVOCORR,
            'CDFORNTRANSP'    => $CDFORNTRANSP,
            'NMPESSIDETOC'    => $NMPESSIDETOC,
            'NMPESSAUTOOC'    => $NMPESSAUTOOC,
            'NRLANCTONF'      => $NRLANCTONF,
            'CDOPERADOR'      => $this->environment->getCdOperador(),
            'CDFILILANCMO'    => $this->environment->getCdFilial(),
            'NROCORRMOV'      => $NROCORRMOV,
            'NRLISTAUTFORN'   => $NRLISTAUTFORN,
            'DTENTRMOVOCORR'  => $DTENTRMOVOCORR
        ];
        
    }

    public function insertDescription($DSMOVOCORR, $CDFILILANCMO, $NROCORRMOV)
    {
        $query = "INSERT INTO DESCMOVOCORR
        (CDFILILANCMO, NROCORRMOV, DSMOVOCORR)
            VALUES
        (:CDFILILANCMO, :NROCORRMOV, :DSMOVOCORR)";

        $params = [
            'CDFILILANCMO' => $CDFILILANCMO,
            'NROCORRMOV'   => $NROCORRMOV
        ];
        
        try {

            $std = $this->connection->prepare($query);

            $std->bindValue(':DSMOVOCORR', $DSMOVOCORR, ParameterType::LARGE_OBJECT);

            $std->execute($params);

        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateDescription($DSMOVOCORR, $CDFILILANCMO, $NROCORRMOV)
    {
        $query = "UPDATE DESCMOVOCORR
        SET
          DSMOVOCORR = :DSMOVOCORR
        WHERE
          CDFILILANCMO = :CDFILILANCMO AND
          NROCORRMOV = :NROCORRMOV";

        $params = [
            'CDFILILANCMO' => $CDFILILANCMO,
            'NROCORRMOV'   => $NROCORRMOV
        ];
        
        try {

            $std = $this->connection->prepare($query);

            $std->bindValue(':DSMOVOCORR', $DSMOVOCORR, ParameterType::LARGE_OBJECT);

            $std->execute($params);

        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insertParecer($DSPAROCORMOV, $CDFILILANCMO, $NROCORRMOV)
    {
        $query = "INSERT INTO PARECER
        (CDFILILANCMO, NROCORRMOV, DSPAROCORMOV)
        values
        (:CDFILILANCMO, :NROCORRMOV, :DSPAROCORMOV)";

        $params = [
            'CDFILILANCMO' => $CDFILILANCMO,
            'NROCORRMOV'   => $NROCORRMOV
        ];

        try {

            $std = $this->connection->prepare($query);

            $std->bindValue(':DSPAROCORMOV', $DSPAROCORMOV, ParameterType::LARGE_OBJECT);

            $std->execute($params);

        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insertFoto($DSFOTOOCORR, $CDFILILANCMO, $NROCORRMOV)
    {
        $query = "INSERT INTO FOTOMOVOCORR
        (CDFILILANCMO, NROCORRMOV, DSFOTOOCORR)
        values
        (:CDFILILANCMO, :NROCORRMOV, :DSFOTOOCORR)";

        $params = [
            'CDFILILANCMO' => $CDFILILANCMO,
            'NROCORRMOV'   => $NROCORRMOV,
            'DSFOTOOCORR'   => $DSFOTOOCORR
        ];


        $std = $this->connection->prepare($query);
        $std->execute($params);

    }

    public function updateFoto($DSFOTOOCORR, $CDFILILANCMO, $NROCORRMOV)
    {
        $query = "UPDATE FOTOMOVOCORR
        SET
            DSFOTOOCORR = :DSFOTOOCORR
        WHERE
          CDFILILANCMO = :CDFILILANCMO AND
          NROCORRMOV = :NROCORRMOV";

          $params = [
            'CDFILILANCMO' => $CDFILILANCMO,
            'NROCORRMOV'   => $NROCORRMOV,
            'DSFOTOOCORR'   => $DSFOTOOCORR
        ];

        try {

            $std = $this->connection->prepare($query);


            $std->execute($params);

        } catch (\Exception $e) {
            throw new \Exception("UPLOADERROR");
        }
    }

    public function updateParecer($DSPAROCORMOV, $CDFILILANCMO, $NROCORRMOV)
    {
        $query = "UPDATE PARECER
        SET
          DSPAROCORMOV = :DSPAROCORMOV
        WHERE
          CDFILILANCMO = :CDFILILANCMO AND
          NROCORRMOV = :NROCORRMOV";

          $params = [
            'CDFILILANCMO' => $CDFILILANCMO,
            'NROCORRMOV'   => $NROCORRMOV
        ];

        try {

            $std = $this->connection->prepare($query);

            $std->bindValue(':DSPAROCORMOV', $DSPAROCORMOV, ParameterType::LARGE_OBJECT);

            $std->execute($params);

        } catch (\Exception $e) {
            throw $e;
        }
    }
}