<?php

namespace Teknisa\GQL\Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class gql00600ToleranciaDasNaoConformidadesService
{
    protected $connection;
    
    public function __construct($entityManager, $environment)
    {
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    /********************
     *      SELECTS     *
     * ******************/
    
    public function getTolerancia ($row)
    {
        $params = [
            'P_CDTIPRISCO'  => $row['CDTIPRISCO'],
            'P_NRMAXOCORR'  => $row['NRMAXOCORR'],
            'P_NRDIASOCORR' => $row['NRDIASOCORR'],
        ];
        
        $query = "SELECT
                       RETORNO
                    FROM
                       (SELECT COUNT(*) RETORNO
                        FROM
                           TOLECONF
                        WHERE
                           (CDTIPRISCO  = :P_CDTIPRISCO) AND
                           (NRMAXOCORR  = :P_NRMAXOCORR) AND
                           (NRDIASOCORR = :P_NRDIASOCORR))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /********************
     *      UPDATES     *
     * ******************/
     
    public function updateTolerancia ($row)
    {
        $params = [
            'CDTIPRISCO'   => $row['CDTIPRISCO'],
            'CDQUALIF'     => $row['CDQUALIF'],
            'NRMAXOCORR'   => $row['NRMAXOCORR'],
            'NRDIASOCORR'  => $row['NRDIASOCORR'],
            'OLD_CDQUALIF' => $row['OLD_CDQUALIF'],
        ];
        
        $query = "UPDATE TOLECONF
                    SET
                      CDTIPRISCO  = :CDTIPRISCO,
                      CDQUALIF    = :CDQUALIF,
                      NRMAXOCORR  = :NRMAXOCORR,
                      NRDIASOCORR = :NRDIASOCORR
                    WHERE
                      CDTIPRISCO  = :CDTIPRISCO AND
                      CDQUALIF    = :OLD_CDQUALIF AND
                      NRMAXOCORR  = :NRMAXOCORR AND
                      NRDIASOCORR = :NRDIASOCORR";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /********************
     *      INSERTS     *
     * ******************/
     
    public function insertTolerancia ($row)
    {
        $params = [
            'CDTIPRISCO'  => $row['CDTIPRISCO'],
            'CDQUALIF'    => $row['CDQUALIF'],
            'NRMAXOCORR'  => $row['NRMAXOCORR'],
            'NRDIASOCORR' => $row['NRDIASOCORR'],
            'NRORG'       => $this->environment->getNrorg(),
        ];
        
        $query = "INSERT INTO TOLECONF
                      (CDTIPRISCO, CDQUALIF, NRMAXOCORR, NRDIASOCORR, NRORG)
                    VALUES
                      (:CDTIPRISCO, :CDQUALIF, :NRMAXOCORR, :NRDIASOCORR, :NRORG)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /********************
     *      DELETES     *
     * ******************/
     
    public function deleteTolerancia ($row)
    {
        $params = [
            'CDTIPRISCO'  => $row['CDTIPRISCO'],
            'CDQUALIF'    => $row['CDQUALIF'],
            'NRMAXOCORR'  => $row['NRMAXOCORR'],
            'NRDIASOCORR' => $row['NRDIASOCORR'],
        ];
        
        $query = "DELETE FROM TOLECONF
                    WHERE
                      CDTIPRISCO = :CDTIPRISCO AND
                      CDQUALIF = :CDQUALIF AND
                      NRMAXOCORR = :NRMAXOCORR AND
                      NRDIASOCORR = :NRDIASOCORR";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
}